package com.ibm.vap.ccfadapter.ims;

/*
 * Source File Name : IMSAdapter.java
 * Licensed Materials - Property of IBM
 * 5655-F37
 * (C) Copyright IBM Corp. 1983, 2002
 */
import com.ibm.connector.*;
import com.ibm.connector.imstoc.*;
import com.ibm.vap.ccfadapter.*;
/**
 * This server adapter class is used by the VisualAge Pacbase Runtime to communicate with
 * the server using IMS Connect/CCF connector.
 * <P>
 * This class implements the ServerAdapter methods using the Common Connector Framework interface for IMS Connect 
 * delivered by IBM. All you need is to set up the IMS Connect environment, instantiate IMSAdapter class and
 * sets it as the current proxy adapter.
 * <P>
 * Sample code :
 * <blockquote>
 * <pre>
 *	// Prepare the infrastructure
 *	com.ibm.connector.connectionmanager.ConnectionManager cm = new com.ibm.connector.connectionmanager.ConnectionManager();
 *	com.ibm.connector.infrastructure.RuntimeContext rc = new com.ibm.connector.infrastructure.RuntimeContext();
 *	rc.setConnectionManager(cm);
 *	com.ibm.connector.infrastructure.java.JavaRuntimeContext.setCurrent(rc);
 *	// Instanciate the connection spec
 * 	com.ibm.connector.imstoc.IMSConnectionSpec connectionSpec = new com.ibm.connector.imstoc.IMSConnectionSpec();
 * 	connectionSpec.setConnectionTimeout(80);
 * 	connectionSpec.setHostName("xxx.xxx.xxx.xxx.xxx");
 * 	connectionSpec.setMaxConnections(10);
 * 	connectionSpec.setMinConnections(1);
 * 	connectionSpec.setPortNumber(4000);
 * 	// Configure the logon info items
 * 	com.ibm.connector.imstoc.IMSLogonInfoItems imslogon = new com.ibm.connector.imstoc.IMSLogonInfoItems(rc.getLogonInfo(), connectionSpec);
 * 	imslogon.setUser("USER");
 * 	imslogon.setPassword("PASSWORD");
 * 	imslogon.setGroup("GROUP");
 *
 * 	com.ibm.connector.imstoc.IMSCommunication communication = (com.ibm.connector.imstoc.IMSCommunication)connectionSpec.createCommunication();
 * 	communication.connect();
 *
 * 	com.ibm.connector.imstoc.IMSInteractionSpec interactionSpec = new com.ibm.connector.imstoc.IMSInteractionSpec();
 * 	interactionSpec.setDataStoreName("DATASTORE");
 * 	interactionSpec.setRASTraceLevel(15);
 * 	interactionSpec.setSyncLevel(com.ibm.connector.imstoc.IMSInteractionSpecProperties.SYNC_LEVEL_NONE);
 * 	interactionSpec.setMode(com.ibm.connector.InteractionSpecModeProperties.MODE_SEND_RECEIVE);
 *
 * 	// Instanciate the adapter class
 *	try {
 *		com.ibm.vap.ccfadapter.ims.IMSAdapter imsa = new com.ibm.vap.ccfadapter.ims.IMSAdapter(connectionSpec, interactionSpec);
 *		imsa.setHostCodePage("Cp037");
 *		imsa.setTransactionName("TRANS");
 *		imsa.setCommareaLength(8192);
 *		// Instantiate a Vap Proxy and set the adapter class
 *		com.ibm.vap.generated.proxies.CustomerProxyLv proxy = new com.ibm.vap.generated.proxies.CustomerProxyLv();
 *		proxy.setServerAdapter(imsa);
 *		proxy.selectInstances();
 *		return proxy.rows();
 *	} catch (com.ibm.vap.generic.CommunicationError ce) {
 *		return ce.getMessage();
 *	} catch (com.ibm.vap.generic.SystemError se) {
 *		return se.getMessage();
 *	}
 * </pre>
 * </blockquote>
 * 
 * @since 3.0v06
 * @see com.ibm.vap.generic.ServerAdapter
 * @version 3.0v06
 */
public class IMSAdapter extends CCFAdapter {
	String transactionName = null;
	private final static String copyright = "Licensed Materials - Property of IBM\n5655-F37\n(C) Copyright IBM Corp. 1983, 2002. All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP\nSchedule Contract with IBM Corp.";
public IMSAdapter() {
	super();
}
public IMSAdapter(ConnectionSpec cs, InteractionSpec is) {
	super(cs, is);
}
protected CCFRequester createRequester() {
	return new IMSRequester(this);
}
protected Communication getCommunication() {
	return super.getCommunication();
}
public String getTransactionName() {
	return transactionName;
}
public void setTransactionName(String tn) {
	transactionName = tn;
}
}
