package com.ibm.vap.ccfadapter.ims;

/*
 * Source File Name : IMSRequester.java
 * Licensed Materials - Property of IBM
 * 5655-F37
 * (C) Copyright IBM Corp. 1983, 2002
 */
import com.ibm.vap.generic.*;
import com.ibm.connector.*;
import com.ibm.connector.imstoc.*;
import com.ibm.vap.ccfadapter.*;
/**
 * Requester dedicated to IMSAdapter using CCF/IMS Connect library
 */
public class IMSRequester extends CCFRequester {
	public final static int TRANSACTION_NAME_SIZE = 8;
	private IMSByteBuffer outIMSByteBuffer;
	private IMSAdapter imsAdapter;
	private final static String copyright = "Licensed Materials - Property of IBM\n5655-F37\n(C) Copyright IBM Corp. 1983, 2002. All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP\nSchedule Contract with IBM Corp.";
protected IMSRequester(IMSAdapter imsa) {
	super(imsa);
}
public IMSAdapter getIMSAdapter() {
	return (IMSAdapter)adapter;
}
public synchronized int receive(char[] message, int offset, int length)
	throws CommunicationError {
	try {
		String out =
			new String(
				outIMSByteBuffer.getBytes(),
				offset + 4,
				length,
				getIMSAdapter().getHostCodePage());
		out.getChars(0, length, message, offset);
		return out.length();
	} catch (java.io.UnsupportedEncodingException uee) {
		throw new CommunicationError("Byte to Char Conversion Error", uee);
	}

}
public int receiveCheck() throws CommunicationError {
	if ((outIMSByteBuffer != null) && (outIMSByteBuffer.getBytes() != null)) {
		return outIMSByteBuffer.getBytes().length;
	} else {
		return 0;
	}
}
public void release() {
	super.release();
	outIMSByteBuffer = null;
}
/**
 * Sends a message to the server.
 * The given message must be passed to the Visualage Pacbase communication monitor at the server side.
 * @param message to be sent to the server
 * @param offset defines the starting charactere where to start sending the message
 * @param length of the message to be sent
 * @return the number of bytes effectively sent
 * @exception CommunicationError if the execute method fails
 */
public synchronized int send( char[] message, int offset, int length ) throws CommunicationError {

	// Allocate the buffer in order to store input bytes
	int headerLength = 2 + 2 + 	TRANSACTION_NAME_SIZE; // LL + ZZ + TransactionName
	int sentLength = headerLength + length;
	byte[] inBuffer = new byte[sentLength];

	// Transaction name stored beginning at the 4th byte
	StringBuffer transactionName = new StringBuffer(TRANSACTION_NAME_SIZE);
	transactionName.append(((IMSAdapter)adapter).getTransactionName());
	while (transactionName.length() < TRANSACTION_NAME_SIZE) transactionName.append(' ');
	try {
		byte[] transaction = transactionName.toString().getBytes(getIMSAdapter().getHostCodePage());
		System.arraycopy(transaction, 0, inBuffer, 4, TRANSACTION_NAME_SIZE);
	} catch (java.io.UnsupportedEncodingException uee) {
		throw new CommunicationError("Char to Byte Conversion Error", uee);
	}

	// Applicative part of the message
	try {
		byte[] inData = new String(message, offset, length).getBytes(getIMSAdapter().getHostCodePage());
		System.arraycopy(inData, 0, inBuffer, headerLength, length);
	} catch (java.io.UnsupportedEncodingException uee) {
		throw new CommunicationError("Char to Byte Conversion Error", uee);
	}

	// Header part of the message
	// LL
	int ll = sentLength;
	inBuffer[0] = (byte)(short)(ll / 256);
	inBuffer[1] = (byte)(short)(ll % 256);
	// ZZ
	int zz = 0;
	inBuffer[2] = (byte)(short)(zz / 256);
	inBuffer[3] = (byte)(short)(zz % 256);
	
	
	//Create Output Object
	outIMSByteBuffer = new IMSByteBuffer(new byte[2 + 2 + TRANSACTION_NAME_SIZE + getIMSAdapter().getCommareaLength()]);

	//Execute
	try {
		((IMSAdapter)adapter).getCommunication().execute(adapter.getInteractionSpec(), new IMSByteBuffer(inBuffer), outIMSByteBuffer);
	}
	catch (CommunicationException ce) {
		throw new CommunicationError(ce.getMessage());
	}
	catch (LogonException le) {
		throw new CommunicationError(le.getMessage());
	}
	catch (IllegalArgumentException iae) {
		throw new CommunicationError(iae.getMessage());
	}
	catch (NotConnectedException nce) {
		throw new CommunicationError(nce.getMessage());
	}
	catch (InvalidTransactionException ite) {
		throw new CommunicationError(ite.getMessage());
	}
	catch (com.ibm.connector.internal.ResourceException re) {
		throw new CommunicationError(re.getMessage());
	}
	return length;
}
}
